%global sname pgbackrest
%global pgmajorversion 16

Summary:  Reliable PostgreSQL Backup & Restore
Name:     postgresql%{pgmajorversion}-%{sname}
Version:  2.51
Release:  1%{?dist}
License:  MIT
Url:      http://www.pgbackrest.org/
Source0:	https://github.com/pgbackrest/pgbackrest/archive/release/%{version}.tar.gz
Source1:	%{sname}-conf.patch
Source2:	%{sname}-tmpfiles.d
Source3:	%{sname}.logrotate
Source4:	%{sname}.service

BuildRequires: 		make gcc
BuildRequires:    	openssl-devel zlib-devel postgresql%{pgmajorversion}-private-devel
# pg_config -> pg_server_config (postgresql-server-devel provides)
BuildRequires:		postgresql%{pgmajorversion}-server-devel
BuildRequires:    	libzstd-devel libxml2-devel libyaml-devel libssh2-devel
BuildRequires:    	lz4-devel bzip2-devel systemd systemd-devel
Requires:	        postgresql%{pgmajorversion}-private-libs
Requires:	        lz4-libs libzstd libssh2
# We require this to be present for %%{_prefix}/lib/tmpfiles.d
Requires:			systemd
Requires(pre):	  	/usr/sbin/useradd /usr/sbin/groupadd
Requires(post):		systemd-sysv
Requires(post):		systemd
Requires(preun):	systemd
Requires(postun):	systemd

%description
pgBackRest aims to be a simple, reliable backup and restore system that can
seamlessly scale up to the largest databases and workloads.

Instead of relying on traditional backup tools like tar and rsync, pgBackRest
implements all backup features internally and uses a custom protocol for
communicating with remote systems. Removing reliance on tar and rsync allows
for better solutions to database-specific backup challenges. The custom remote
protocol allows for more flexibility and limits the types of connections that
are required to perform a backup which increases security.

%prep
%autosetup -n %{sname}-release-%{version}

%build
pushd src
%configure
%make_build
popd

%install
%{__install} -D -d -m 0755 %{buildroot}%{perl_vendorlib} %{buildroot}%{_bindir}
%{__install} -D -d -m 0700 %{buildroot}/%{_sharedstatedir}/%{sname}
%{__install} -D -d -m 0700 %{buildroot}%{_localstatedir}/log/%{sname}
%{__install} -D -d -m 0700 %{buildroot}%{_localstatedir}/spool/%{sname}
%{__install} -D -d -m 0755 %{buildroot}%{_sysconfdir}
%{__install} %{SOURCE1} %{buildroot}/%{_sysconfdir}/%{sname}.conf
%{__cp} -a src/%{sname} %{buildroot}%{_bindir}/%{sname}

# Install logrotate file:
%{__install} -p -d %{buildroot}%{_sysconfdir}/logrotate.d
%{__install} -p -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/logrotate.d/%{sname}

# ... and make a tmpfiles script to recreate it at reboot.
%{__mkdir} -p %{buildroot}/%{_tmpfilesdir}
%{__install} -m 0644 %{SOURCE2} %{buildroot}/%{_tmpfilesdir}/%{sname}.conf

# Install unit file:
%{__install} -d %{buildroot}%{_unitdir}
%{__install} -m 644 %{SOURCE4} %{buildroot}%{_unitdir}/%{sname}.service

%pre
# PGDATA needs removal of group and world permissions due to pg_pwd hole.
%{__install} -d -m 700 %{_localstatedir}/lib/pgsql/
groupadd -g 26 -o -r postgres >/dev/null 2>&1 || :
useradd -M -g postgres -o -r -d %{_localstatedir}/lib/pgsql -s /bin/bash \
	-c "PostgreSQL Server" -u 26 postgres >/dev/null 2>&1 || :
%{__chown} postgres: %{_localstatedir}/lib/pgsql

%post
if [ $1 -eq 1 ] ; then
   /bin/systemctl daemon-reload >/dev/null 2>&1 || :
   %systemd_post %{sname}.service
fi

%preun
if [ $1 -eq 0 ] ; then
	# Package removal, not upgrade
	/bin/systemctl --no-reload disable %{sname}.service >/dev/null 2>&1 || :
	/bin/systemctl stop %{sname}.service >/dev/null 2>&1 || :
fi

%postun
/bin/systemctl daemon-reload >/dev/null 2>&1 || :

if [ $1 -ge 1 ] ; then
	# Package upgrade, not uninstall
	/bin/systemctl try-restart %{sname}.service >/dev/null 2>&1 || :
fi

%files
%license LICENSE
%{_bindir}/%{sname}
%config(noreplace) %attr (644,root,root) %{_sysconfdir}/%{sname}.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/%{sname}
%{_tmpfilesdir}/%{sname}.conf
%{_unitdir}/%{sname}.service
%attr(-,postgres,postgres) %{_localstatedir}/log/%{sname}
%attr(-,postgres,postgres) %{_sharedstatedir}/%{sname}
%attr(-,postgres,postgres) %{_localstatedir}/spool/%{sname}

%changelog
* Fri Apr 12 2024 Wang Guodong <gordonwwang@tencent.com> - 2.51-1
- init build
